from unittest import TestCase

from model.data import Game, Player


class TestGame(TestCase):
    def setUp(self) -> None:
        super().setUp()
        self.player1 = Player("PLN")
        self.player2 = Player("Nassim")
        self.game = Game([self.player1, self.player2])

    def test_global_hand(self) -> None:
        card1 = self.game.deck.random_card()
        self.player1.give(card1)

        card2 = self.game.deck.random_card()
        card3 = self.game.deck.random_card()
        self.player2.give(card2)
        self.player2.give(card3)

        self.assertTrue(card1 in self.game.global_hand, "Global hand should contain player1's card")
        self.assertTrue(card2 in self.game.global_hand, "Global hand should contain player2's first card")
        self.assertTrue(card3 in self.game.global_hand, "Global hand should contain player2's second card")

    def test_turn(self):
        self.game.new_turn()

        self.assertEqual(1, len(self.game.defeats.values()), "There should have been one defeat.")
        self.assertTrue(1 in self.game.defeats.values(), "A player should have one defeat.")

    def test_full_game(self):
        self.game.new_game()

        self.assertGreater(len(self.game.defeats.values()), 0, "There should be at least one player with defeats.")
        self.assertTrue(5 in self.game.defeats.values(), "A player should have lost five times.")
